@@ -84,7 +84,7 @@ def process_file(assets_dir, assets_from_page_dir, file, subdir):
         file_path = os.path.join(subdir, file)
         if DEBUG:
             print('processing %s' % file_path)
-        with open(file_path) as md:
+        with open(file_path, encoding='utf8') as md:
             try:
                 numbered_lines = enumerate(line for line in md)
             except:
